@@ -16,12 +16,14 @@ dj <- diag(csums)
 di <- diag(rsums)
 uni <- matrix(1, 1, ncol(x))
 uni1 <- rep(1, nrow(x))
-Bpoly <- emerson.poly(mj, csums)
+Bpoly <- emerson.poly(mj, csums)$B
 Bpoly2 <- sqrt(dj) %*% Bpoly
 pcc <- 1/sqrt(tauden)* ( x%*%dcm1 - rsums %*% (uni) ) 
+u<-svd(pcc%*%sqrt(dj))$u
 
-u<-svd(pcc)$u
+#Z <- t(u)  %*%pcc %*% sqrt(dj)%*%Bpoly2
 Z <- t(u)  %*%pcc %*% dj%*%Bpoly
+
 ZtZ<-Z%*%t(Z)
 tZZ<-t(Z)%*%Z
 mu2<- diag(tZZ) #only the sum gives me the total inertia
